"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.valueListCommaWhitespaceChecker = valueListCommaWhitespaceChecker;

var _utils = require("../../utils");

var ruleName = "value-list-comma-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \",\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected whitespace after \",\"";
  },
  expectedAfterSingleLine: function expectedAfterSingleLine() {
    return "Expected single space after \",\" in a single-line list";
  },
  rejectedAfterSingleLine: function rejectedAfterSingleLine() {
    return "Unexpected whitespace after \",\" in a single-line list";
  }
});

exports.messages = messages;

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("space", expectation, messages);
  return function (root, result) {
    var validOptions = (0, _utils.validateOptions)(result, ruleName, {
      actual: expectation,
      possible: ["always", "never", "always-single-line", "never-single-line"]
    });
    if (!validOptions) {
      return;
    }

    valueListCommaWhitespaceChecker(checker.after, root, result);
  };
};

function valueListCommaWhitespaceChecker(checkLocation, root, result) {
  root.eachDecl(function (decl) {
    var value = decl.value;

    (0, _utils.styleSearch)({ source: value, target: ",", outsideFunctionalNotation: true }, function (match) {
      checkComma(value, match.startIndex, decl);
    });
  });

  function checkComma(source, index, node) {
    checkLocation({ source: source, index: index, err: function err(m) {
        return (0, _utils.report)({
          message: m,
          node: node,
          result: result,
          ruleName: ruleName
        });
      }
    });
  }
}